#!/bin/bash

# Packager : JP Guillemin jp.guillemin@free.fr

soft='gnome-mplayer'
softversion='0.9.2'
packageversion='54.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="/tmp/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"

cd $src
./configure --prefix=/usr \
			--with-alsa \
			--without-gconf \
			--with-libnotify \
			--sysconfdir=/etc \
			--localstatedir=/var

make DESTDIR=$dest
make install DESTDIR=$dest


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# redundant
rm -rf $dest/usr/share/doc

# Desktop file
mkdir -p $dest/usr/share/applications
rm -rf $dest/usr/share/gnome

cat << "EOF" > $dest/usr/share/applications/gnome-mplayer.desktop
[Desktop Entry]
Version=1.0
Type=Application
Encoding=UTF-8
Name=Gnome Mplayer
GenericName=Gnome Mplayer
Comment=Multimedia player
Comment[de]=Multimedia-Player
Comment[es]=Reproductor multimedia
Comment[fr]=Lecteur multimedia
Comment[it]=Lettore multimediale
Icon=gnome-mplayer
TryExec=gmp
Exec=gmp %F
Terminal=false
Categories=X-XFCE;Application;AudioVideo;AudioPlayer;VideoPlayer;
StartupNotify=true
MimeType=application/x-annodex;audio/x-ogg;audio/x-speex;application/x-ogg;video/x-ms-asf;video/x-ms-wmv;video/x-ms-wma;application/vnd.ms-asf;application/x-mplayer2;video/x-ms-asf-plugin;video/x-ms-wvx;video/x-ms-wax;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;video/msvideo;video/x-msvideo;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/x-flic;audio/x-pn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mkv;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;video/mpeg;video/x-mpeg;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;audio/x-mpegurl;audio/mpegurl;audio/mp3;audio/x-mp3;application/x-flac;

EOF

# The launcher
cat << "EOF" > $dest/usr/bin/gmp
#!/bin/bash
# launcher script for Gnome-Mplayer - Jean-Philippe Guillemin <jp.guillemin@free.fr> 
# 
OPTIONS=" --vertical --showplaylist --single_instance --replace_and_play"
exec /usr/bin/gnome-mplayer ${OPTIONS} "$@"

EOF
chmod 755 $dest/usr/bin/gmp

# Icons go to hicolor
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
# mv $dest/usr/share/pixmaps/* $dest/usr/share/icons/hicolor/48x48/apps/
cp $buildir/gnome-mplayer.png $dest/usr/share/icons/hicolor/48x48/apps/
rm -rf $dest/usr/share/pixmaps

# Description file
mkdir -p $dest/install

cat << "EODESC" > $dest/install/slack-desc
gnome-mplayer: Gnome-Mplayer - Finest MPlayer frontend
gnome-mplayer:
gnome-mplayer: GNOME MPlayer is intended to be a nice tight player and 
gnome-mplayer: provide a simple and clean interface to MPlayer. GNOME 
gnome-mplayer: MPlayer has a rich API that is exposed via DBus. Using 
gnome-mplayer: DBus you can control a single or multiple instances of 
gnome-mplayer: GNOME MPlayer from a single command.
gnome-mplayer:
gnome-mplayer:
gnome-mplayer:
EODESC

# Documentation
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING INSTALL README ChangeLog $dest/usr/doc/$soft-$softversion
cp -a DOCS/tech/* $dest/usr/doc/$soft-$softversion
mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.tgz

# cleanup 
rm -rf $dest
rm -rf $src
